Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// Width sets the width of the Grid
Width int
// Height sets the height of the Grid
Height int
// NFrames is the amount of frames that will be built
NFrames int
Simulation models.SimulationConfig
Output OutputConfig
GIF GIFConfig
}
Config holds configs for the simulation runner
type GIFConfig ¶
type GIFConfig struct {
// Delay units are 100th of a second
Delay int
}
GIFConfig holds configurations specific to building a GIF
type OutputConfig ¶
type OutputConfig struct {
Path string
}
OutputConfig holds configs for the output of the simulation
Click to show internal directories.
Click to hide internal directories.